@@ -27,7 +27,7 @@ from calculate.core.server.methods_func import get_password
 from calculate.lib.cl_lang import setLocalTranslate
 from calculate.lib.utils.common import getpass
 from calculate.lib.utils.files import listDirectory
-setLocalTranslate('calculate_console',sys.modules[__name__])
+setLocalTranslate('cl_console3',sys.modules[__name__])
 VERSION = 0.11
 
 def client_post_cert (client, clVars, show_info = False):
@@ -39,16 +39,20 @@ def client_post_cert (client, clVars, show_info = False):
     result_post_cert = _result_post_cert[1].integer
     result_sid = _result_sid[1].integer
 
+    print _("the client uses certificate %s") %client.CERT_FILE
+    print  result_post_cert[0]
     if result_post_cert[0] == -4:
         print _("Certificate not found on the server")
-        print _('client uses certificate %s') %client.CERT_FILE
-        print _('You can generate a new certificate using --gen-cert-by and '\
+        print _("the client uses certificate %s") %client.CERT_FILE
+        print _('You can generate a new certificate using options --gen-cert-by and '\
                 '--get-cert-from')
         raise Exception(3)
 
 #    client_sid(sid, client, cert_id = results[0][0], clVars = clVars)
     if result_post_cert[0] == -3:
         print _("Certificate not sent!")
+    elif result_post_cert[0] == -2:
+        print _("Using the upstream certificate")
     else:
         if show_info:
             print _(" Your certifitate ID = %d") %(result_post_cert[0])
@@ -118,7 +122,7 @@ def delete_old_cert(client):
 def client_post_request (cert_path, args):
     if os.path.exists(cert_path + 'req_id'):
         print \
-            _("You have already sent a signature request for the certificate.")
+            _("You already sent a certificate signature request.")
         _print (_("Request ID = %s") %open(cert_path + 'req_id', 'r').read())
         ans = raw_input (_("Send a new request? y/[n]: "))
         if not ans.lower() in ['y','yes']:
@@ -141,7 +145,7 @@ def client_post_request (cert_path, args):
     key = os.path.join(cert_path, server_host_name + '.key')
     csr_file = os.path.join(cert_path, server_host_name +'.csr')
     if os.path.exists(key) and os.path.exists(csr_file):
-        print _('private key and request now exist')
+        print _("the private key and request now exist")
         ask = raw_input(_("Create a new private key and request? y/[n]: "))
         if ask.lower() in ['y','yes']:
             passwd = get_password()
@@ -157,13 +161,13 @@ def client_post_request (cert_path, args):
     res = client.service.post_client_request(request = data, ip = ip,\
                                     mac = mac, client_type = client_type)
     if int(res) < 0:
-        print _("This server has not signed the certificate!")
+        print _("The server has not signed the certificate!")
         return 1
     fc = open(os.path.join(cert_path, 'req_id'), 'w')
     fc.write(res)
     fc.close()
     _print (_("Your request ID = %s") %res + '.\n',
-            _("To sign the certificate in the server use command") + \
+            _("To submit the certificate request on the server use command") + \
            '\n'+'cl-core --sign-client ID_CLIENT_REQUEST')
     return 0
     
@@ -205,16 +209,16 @@ def client_get_cert(cert_path, args):
     except IndexError:
         ca_root = None
     if cert == '1':
-        print _('Request to sign is rejected!')
+        print _("Signature request rejected!")
         return 1
     elif cert == '2':
-        print _("Signature request not reviewed yet.")
+        print _("Signature request not examined yet.")
         print _("Your request ID = %s") %req_id + '.\n',\
-              _("To sign the certificate in the server use command") + \
+              _("To submit the certificate request on the server use command") + \
               '\n'+'cl-core --sign-client ID_CLIENT_REQUEST'
         return 1
     elif cert == '3':
-        print _("Signature request not matching earlier data.")
+        print _("Request or signature not matching earlier data.")
         return 1
     elif cert == '4':
         print _("The request was sent from another IP.")
@@ -241,12 +245,12 @@ def client_get_cert(cert_path, args):
         clVars = DataVarsCore()
         clVars.importCore()
         clVars.flIniFile()
-        system_ca_db = clVars.Get('cl_glob_root_cert')
+        system_ca_db = clVars.Get('core.cl_glob_root_cert')
         if os.path.exists(system_ca_db):
             if ca_root in open(system_ca_db, 'r').read():
                 return 0
 
-        cl_client_cert_dir = clVars.Get('cl_client_cert_dir')
+        cl_client_cert_dir = clVars.Get('core.cl_client_cert_dir')
         homePath = clVars.Get('ur_home_path')
 
         cl_client_cert_dir = cl_client_cert_dir.replace("~",homePath)
@@ -292,7 +296,7 @@ def client_get_cert(cert_path, args):
             fd.close()
             
             
-            user_root_cert = clVars.Get('cl_user_root_cert')
+            user_root_cert = clVars.Get('core.cl_user_root_cert')
             user_root_cert = user_root_cert.replace("~",homePath)
             fa = open(user_root_cert, 'a')
             fa.write(ca_root)
@@ -300,7 +304,7 @@ def client_get_cert(cert_path, args):
             print _("filename = "), filename
             print _("Certificate added")
         else:
-            print _("A file with CA certificates now exists")
+            print _("The file containing the CA certificate now exists")
     return 0
     
 def client_post_auth(client):
@@ -312,9 +316,7 @@ def client_post_auth(client):
             pass#client_post_cert(client)
         else:
             #client_post_request(client)
-            print _("You do not have a certificate. Use --gen-cert-by HOST "
-                    "to generate a new request or --get-cert-from HOST to "
-                    "get a new certificate from the server.")
+            print _("You do not have a certificate. Use option --gen-cert-by HOST to generate a new request or --get-cert-from HOST to get a new certificate from the server.")
             raise Exception(1)
 #        print client.service.versions(sid, VERSION)
     except VerifyError, e:
@@ -520,4 +522,4 @@ def get_password_from_daemon(server_host, server_port, wait_thread):
 #    else:
 #        password = resp if resp else None
 #    return password
-######################### End get password
\ No newline at end of file
+######################### End get password
