@@ -23,11 +23,12 @@ from OpenSSL import crypto
 import shlex
 from sudsds import MethodNotFound
 from calculate.core.server.cert_cmd import getHwAddr, getIpLocal
+from calculate.core.server.replace_class import printTable
 
 from calculate.core.client.progressbar import Bar,Percentage,ETA,ProgressBar
 from calculate.lib.cl_lang import setLocalTranslate
 from calculate.lib.cl_print import color_print
-setLocalTranslate('calculate_console',sys.modules[__name__])
+setLocalTranslate('cl_console3',sys.modules[__name__])
 from calculate.core.client.function import create_obj
 
 green = '\033[32m * \033[0m'
@@ -213,8 +214,8 @@ def print_brief_group(Fields, group_name):
                 print_group_flag = True
             colorPrint._printSUCCESS('%s: ' %(field.label))
             res = printTable(data, head)
+            sys.stdout.write(res+"\n")
             sys.stdout.flush()
-            sys.stdout.write(res)
 
         else:
             uncompatible_count += 1
@@ -254,42 +255,6 @@ def show_view(view):
     return
     print "+====== show view! ======+"
 
-def printTable(data, header=None ):
-    res = []
-    for row in data:
-        encode_row = map(lambda x: x.encode('utf-8') if x else '', row)
-        res.append(encode_row)
-    data = res
-
-    if type(header) == list:
-        header = map(lambda x: x.encode('utf-8'), header)
-
-    lens = [0]*len(data[0])
-    for row in data:
-        for numCol, column in enumerate(row):
-            cLen = len(unicode(str(column).decode('utf-8')))
-            if lens[numCol] < cLen:
-                lens[numCol] = cLen
-    res = ""
-    spacer = lambda lenList: '+' + '+'.join( '-'*(x+2) for x in lenList ) + '+'
-    drawRow = lambda lenList, valueList: '|' + "".join(
-            ' %s ' % item + ' ' * (lenList[num] - \
-            len(unicode(str(item).decode('utf-8')))) + '|'
-            for num, item in enumerate(valueList) )
-    if header:
-        for numCol, column in enumerate(header):
-            cLen = len(unicode(str(column).decode('utf-8')))
-            if lens[numCol] < cLen:
-                lens[numCol] = cLen
-        res += spacer(lens)+ "\n"
-        res += drawRow( lens, header )+ "\n"
-
-    res+= spacer(lens) + "\n"
-    for r in data:
-        res += drawRow( lens, r )+ "\n"
-    res+= spacer(lens)+ "\n"
-    return res
-
 def show_table(table, item):
     if item.message:
         colorPrint._printSUCCESS(item.message)
@@ -300,8 +265,8 @@ def show_table(table, item):
             data.append(line.string)
 
     res = printTable(data, head)
+    sys.stdout.write(res+"\n")
     sys.stdout.flush()
-    sys.stdout.write(res)
 
 def show_error(item):
     if item.message:
@@ -353,11 +318,13 @@ def _create_obj(client, method):
         raise Exception(1)
     return view_params
 
-def get_view_params(client, method, step = None, expert = None, brief = None):
+def get_view_params(client, method, step = None, expert = None, brief = None, 
+                    onlyhelp = False):
     view_params = _create_obj(client, method)
     view_params.step = step
     view_params.expert = expert
     view_params.brief = brief
+    view_params.onlyhelp = onlyhelp
     return view_params
 
 def callView(client, item, sid):
@@ -380,7 +347,7 @@ def analysis(client, sid, s):
             try:
                 pid = int(mess.message)
             except:
-                show_error(_('the server sent pid = ') + pid)
+                show_error(_('the server sent PID = ') + pid)
                 return 1
             get_messages(client, sid, pid)
         elif mess.type == 'error':
@@ -391,7 +358,7 @@ def analysis(client, sid, s):
 def get_message(client, item, sid, pid):
     """ get one message by its type """
     for case in switch(item.type):
-        if case('normal'):
+        if case('normal') or case('plain'):
 #            sys.stdout.flush()
 #            sys.stdout.write('\x1b[1;33m' + item.message + '\033[0m')
             if item.message:
@@ -512,11 +479,11 @@ def get_Progress(client, sid, pid, id):
         percent = returnProgr.percent
     if percent < 0:
 #        print_progress(returnProgr, error = True)
-        pbar.update(0 - returnProgr.percent)
+        pbar.update(0)# - returnProgr.percent)
         pbar.finish()
     else:
 #        print_progress(returnProgr)
-        pbar.update(returnProgr.percent)
+        pbar.update(100)#returnProgr.percent)
         pbar.finish()
 
 def cout_progress(string):
