@@ -24,6 +24,7 @@ class DataVarsConsole(DataVars):
 
     def importConsole(self, **args):
         '''Заполнить конфигурацию переменных, для десктопа'''
-        self.importData()
-        self.importData('calculate.core.variables')
-        self.importData('calculate.console.variables')
+        self.importVariables()
+        self.importVariables('calculate.core.variables')
+        self.importVariables('calculate.console.variables')
+        self.defaultModule = "console"
