@@ -18,7 +18,7 @@ import sys
 from os import path
 
 from calculate.lib.cl_lang import setLocalTranslate
-setLocalTranslate('cl_gui',sys.modules[__name__])
+setLocalTranslate('cl_console3',sys.modules[__name__])
 
 
 class VariableClGuiData(Variable):
@@ -38,4 +38,4 @@ class VariableClGuiImagePath(Variable):
     """
     Variable store path to images
     """
-    value = '/usr/share/calculate/themes'
\ No newline at end of file
+    value = '/usr/share/calculate/themes'
